import * as React from 'react';
import { PureComponent } from 'react';
import { PropTypes } from 'prop-types';
import SyntaxHighlighter from 'react-syntax-highlighter';
import { normalizeLanguage, languageList } from './supportedLanguages';
import { applyTheme } from './themes/themeBuilder';
export default class CodeBlock extends PureComponent {
    render() {
        const { language } = this.props;
        const { lineNumberContainerStyle, codeBlockStyle, codeContainerStyle } = applyTheme(this.props.theme);
        const props = {
            language: normalizeLanguage(language),
            style: codeBlockStyle,
            showLineNumbers: this.props.showLineNumbers,
            PreTag: 'span',
            codeTagProps: { style: codeContainerStyle },
            lineNumberContainerStyle
        };
        return (React.createElement(SyntaxHighlighter, Object.assign({}, props), this.props.text.toString()));
    }
}
CodeBlock.displayName = 'CodeBlock';
CodeBlock.propTypes = {
    /** The code to be formatted */
    text: PropTypes.string.isRequired,
    /** The language in which the code is written */
    language: PropTypes.oneOf(languageList),
    /** Indicates whether or not to show line numbers */
    showLineNumbers: PropTypes.bool,
    /** A custom theme to be applied, implements the Theme interface */
    theme: PropTypes.object
};
CodeBlock.defaultProps = {
    showLineNumbers: true,
    language: 'md',
    theme: {}
};
//# sourceMappingURL=CodeBlock.js.map